import Link from "next/link";
import Image from "next/image";
import React from "react";
import {ApiConfig, handleApiRequest} from "@/app/services/apiConfig";
import {getTranslations} from "next-intl/server";

export const metadata = {
    title: "About us - Egypco pharma website",
    description: "We are a pharmaceutical company that provides high-quality products and services to our customers.",
};
export default async function AboutUs() {
    const aboutUs = await handleApiRequest(ApiConfig.endpoints.aboutUs);
    const t = await getTranslations("aboutUs")
    return (
        <>
            <section className="relative table w-full py-36 lg:py-44  bg-no-repeat bg-center bg-cover"
                     style={{backgroundImage: `url(${aboutUs?.page_hero?.background_image || '/images/company/aboutus.jpg'})`}}>
                <div className="absolute inset-0 bg-black opacity-75"></div>
                <div className="container relative">
                    <div className="grid grid-cols-1 pb-8 text-center mt-10">
                        <h3 className="mb-6 md:text-4xl text-3xl md:leading-normal leading-normal font-medium text-white">{aboutUs?.page_hero?.name || t("aboutUs")}</h3>

                        <p className="text-slate-300 text-lg max-w-xl mx-auto">{aboutUs?.page_hero?.slogan || ""}</p>
                    </div>
                </div>
            </section>
            <div className="relative">
                <div
                    className="shape absolute sm:-bottom-px -bottom-[2px] start-0 end-0 overflow-hidden z-1 text-white dark:text-slate-900">
                    <svg className="w-full h-auto scale-[2.0] origin-top" viewBox="0 0 2880 48" fill="none"
                         xmlns="http://www.w3.org/2000/svg">
                        <path d="M0 48H1437.5H2880V0H2160C1442.5 52 720 0 720 0H0V48Z" fill="currentColor"></path>
                    </svg>
                </div>
            </div>
            <section className="relative md:py-24 py-16 bg-gray-50 dark:bg-slate-800 px-10 lg:px-0">
                <div className="container relative md:mt-24 mt-16">
                    <div className="grid md:grid-cols-2 grid-cols-1 items-center gap-[30px]">
                        <div className="relative order-1 md:order-2">
                            <Image src={aboutUs?.company?.side_image || "/images/about2.jpg"} placeholder="blur"
                                   blurDataURL="/images/about2.jpg" width={0} height={0} sizes="100vw"
                                   unoptimized={true}
                                   style={{width: "100%", height: "auto"}}
                                   className="rounded-lg shadow-md dark:shadow-gray-800" alt=""/>
                        </div>

                        <div className="lg:me-8 order-2 md:order-1">
                            <h4 className="mb-4 md:text-3xl text-2xl md:leading-normal leading-normal font-semibold">{aboutUs?.company?.title}</h4>
                            <div className="text-slate-400"
                                 dangerouslySetInnerHTML={{__html: aboutUs?.company?.description||""}}/>
                            {/*<ul className="list-none text-slate-400 mt-4">*/}
                            {/*    <li className="mb-1 flex items-center"><BsCheckCircle*/}
                            {/*        className="text-main text-base me-2"/> Quality control and assurance*/}
                            {/*    </li>*/}
                            {/*    <li className="mb-1 flex items-center"><BsCheckCircle*/}
                            {/*        className="text-main text-base me-2"/> Certifications and compliance*/}
                            {/*    </li>*/}
                            {/*    <li className="mb-1 flex items-center"><BsCheckCircle*/}
                            {/*        className="text-main text-base me-2"/> Manufacturing and production*/}
                            {/*    </li>*/}
                            {/*</ul>*/}

                        </div>
                    </div>
                </div>

                <div className="container relative md:mt-24 mt-16">
                    <div className="grid md:grid-cols-2 grid-cols-1 items-center mt-16 gap-[30px]">
                        <div className="relative">
                            <div className="md:me-10">
                                <Image src={aboutUs?.factory?.side_image || "/images/about.jpg"} width={0} height={0}
                                       sizes="100vw"
                                       style={{width: "100%", height: "auto"}} placeholder="blur"
                                       unoptimized={true}
                                       blurDataURL="/images/about.jpg"
                                       className="rounded-lg shadow-md dark:shadow-gray-800" alt=""/>
                            </div>

                        </div>

                        <div className="lg:ms-8 mt-8 md:mt-0">
                            <h4 className="mb-4 md:text-3xl text-2xl md:leading-normal leading-normal font-semibold">{aboutUs?.factory?.title}</h4>
                            <div className="text-slate-400"
                                 dangerouslySetInnerHTML={{__html: aboutUs?.factory?.description||""}}/>

                        </div>
                    </div>
                </div>
            </section>
            <section className="relative md:py-24 py-16 bg-gray-50 dark:bg-slate-800 px-10 lg:px-0">
                <div className="container relative md:mt-24 mt-16">
                    <div className="grid md:grid-cols-2 grid-cols-1 items-center gap-[30px]">
                        <div className="relative order-1 md:order-2">
                            <Image src={aboutUs?.vision?.image || "/images/about2.jpg"} placeholder="blur"
                                   blurDataURL="/images/about2.jpg" width={0} height={0} sizes="100vw"
                                   unoptimized={true}
                                   style={{width: "100%", height: "auto"}}
                                   className="rounded-lg shadow-md dark:shadow-gray-800" alt=""/>
                        </div>

                        <div className="lg:me-8 order-2 md:order-1">
                            <h4 className="mb-4 md:text-3xl text-2xl md:leading-normal leading-normal font-semibold">{t("ourVision")}</h4>
                            <div className="text-slate-400" dangerouslySetInnerHTML={{__html: aboutUs?.vision?.title||""}}/>
                            {/*<ul className="list-none text-slate-400 mt-4">*/}
                            {/*    <li className="mb-1 flex items-center"><BsCheckCircle*/}
                            {/*        className="text-main text-base me-2"/> Quality control and assurance*/}
                            {/*    </li>*/}
                            {/*    <li className="mb-1 flex items-center"><BsCheckCircle*/}
                            {/*        className="text-main text-base me-2"/> Certifications and compliance*/}
                            {/*    </li>*/}
                            {/*    <li className="mb-1 flex items-center"><BsCheckCircle*/}
                            {/*        className="text-main text-base me-2"/> Manufacturing and production*/}
                            {/*    </li>*/}
                            {/*</ul>*/}

                        </div>
                    </div>
                </div>

                <div className="container relative md:mt-24 mt-16">
                    <div className="grid md:grid-cols-2 grid-cols-1 items-center mt-16 gap-[30px]">
                        <div className="relative">
                            <div className="md:me-10">
                                <Image src={aboutUs?.mission?.image || "/images/about.jpg"} width={0} height={0}
                                       sizes="100vw"
                                       style={{width: "100%", height: "auto"}} placeholder="blur"
                                       unoptimized={true}
                                       blurDataURL="/images/about.jpg"
                                       className="rounded-lg shadow-md dark:shadow-gray-800" alt=""/>
                            </div>

                        </div>

                        <div className="lg:ms-8 mt-8 md:mt-0">
                            <h4 className="mb-4 md:text-3xl text-2xl md:leading-normal leading-normal font-semibold">{t("ourMission")}</h4>
                            <div className="text-slate-400" dangerouslySetInnerHTML={{__html: aboutUs?.mission.title||""}}/>

                        </div>
                    </div>
                </div>
            </section>

            <section className="relative md:py-24 py-16 lg:px-0 px-10">
                <div className="container relative">
                    <div className="grid md:grid-cols-2 grid-cols-1 pb-8 items-center">
                        <div>
                            <h6 className="text-main text-sm font-bold uppercase mb-2">{t("ourValue")}</h6>
                            <h3 className="md:text-3xl md:leading-normal text-2xl leading-normal font-semibold mb-4 md:mb-0">{aboutUs?.values?.section_title}</h3>
                        </div>

                    </div>
                    <div className="grid lg:grid-cols-4 md:grid-cols-2 grid-cols-1 mt-8 gap-[30px]">
                        {
                            aboutUs?.values?.data?.map((data, index) => {
                                // let Icons = data.icon
                                return (

                                    <div key={index}
                                         className="group relative p-6 shadow dark:shadow-gray-800 hover:shadow-md dark:hover:shadow-gray-700 hover:bg-main dark:hover:bg-main transition-all duration-500 ease-in-out rounded-xl bg-white dark:bg-slate-900 overflow-hidden text-center">
                                        {/*<div className="relative overflow-hidden text-transparent -m-3">*/}
                                        {/*    <Icon.Hexagon*/}
                                        {/*        className="size-24 fill-main/5 group-hover:fill-white/10 mx-auto rotate-90"></Icon.Hexagon>*/}
                                        {/*    <div*/}
                                        {/*        className="absolute top-2/4 -translate-y-2/4 start-0 end-0 mx-auto text-main rounded-xl group-hover:text-white transition-all duration-500 ease-in-out text-3xl flex align-middle justify-center items-center">*/}
                                        {/*        <Icons width={30} height={30}/>*/}
                                        {/*    </div>*/}
                                        {/*</div>*/}

                                        <div className="mt-6">
                                            <Link href="#"
                                                  className="text-lg font-medium group-hover:text-white transition-all duration-500 ease-in-out">{data.title}</Link>
                                            <p className="text-slate-400 group-hover:text-white/50 transition-all duration-500 ease-in-out mt-3">{data?.description || "It is a long established fact that a reader."}</p>
                                        </div>
                                    </div>
                                )
                            })
                        }
                    </div>
                </div>


            </section>

            <section
                className="relative md:py-24 py-16 lg:px-0 px-10 bg-gradient-to-b from-main to-main-gradient dark:from-secondary dark:to-secondary-hover">
                <div className="container relative">
                    <div className="grid md:grid-cols-2 grid-cols-1 pb-8 items-center">
                        <div>
                            <h6 className="text-white text-sm font-bold uppercase mb-2">{t("ourGoal")}</h6>
                            <h3 className="md:text-3xl md:leading-normal text-2xl leading-normal font-semibold mb-4 md:mb-0">{aboutUs?.goals?.section_title}</h3>
                        </div>

                    </div>
                    <div className="grid lg:grid-cols-4 md:grid-cols-2 grid-cols-1 mt-8 gap-[30px]">
                        {
                            aboutUs?.goals?.data?.map((data, index) => {
                                // let Icons = data.icon
                                return (

                                    <div key={index}
                                         className="group relative p-6 shadow dark:shadow-gray-800  hover:-translate-y-2 hover:shadow-md dark:hover:shadow-gray-700 hover:bg-main dark:hover:bg-main transition-all duration-500 ease-in-out rounded-xl bg-white dark:bg-slate-900 overflow-hidden text-center">
                                        {/*<div className="relative overflow-hidden text-transparent -m-3">*/}
                                        {/*    <Icon.Hexagon*/}
                                        {/*        className="size-24 fill-main/5 group-hover:fill-white/10 mx-auto rotate-90"></Icon.Hexagon>*/}
                                        {/*    <div*/}
                                        {/*        className="absolute top-2/4 -translate-y-2/4 start-0 end-0 mx-auto text-main rounded-xl group-hover:text-white transition-all duration-500 ease-in-out text-3xl flex align-middle justify-center items-center">*/}
                                        {/*        <Icons width={30} height={30}/>*/}
                                        {/*    </div>*/}
                                        {/*</div>*/}

                                        <div className="mt-6">
                                            <Link href="#"
                                                  className="text-lg font-medium group-hover:text-white transition-all duration-500 ease-in-out">{data.title}</Link>
                                            <p className="text-slate-400 group-hover:text-white/50 transition-all duration-500 ease-in-out mt-3">{data?.description || "It is a long established fact that a reader."}</p>
                                        </div>
                                    </div>
                                )
                            })
                        }
                    </div>
                </div>


            </section>

            {/*<section className="relative md:py-24 py-16 md:mt-24 mt-16 bg-gray-50 dark:bg-slate-800 md:pt-0 pt-0">*/}
            {/*    <div className="container relative">*/}
            {/*        <div className="grid grid-cols-1 justify-center pt-10">*/}
            {/*            <div className="relative z-1">*/}
            {/*                /!*<div className="grid lg:grid-cols-12 grid-cols-1 md:text-start text-center justify-center">*!/*/}
            {/*                /!*    <div className="lg:col-start-2 lg:col-span-10">*!/*/}
            {/*                /!*        /!*<div className="relative">*!/*!/*/}
            {/*                /!*        /!*    <Image src="/images/cta-bg.jpg" width={0} height={0} sizes='100vw'*!/*!/*/}
            {/*                /!*        /!*           style={{width: "100%", height: "auto"}} className="rounded-md shadow-lg"*!/*!/*/}
            {/*                /!*        /!*           alt=""/>*!/*!/*/}

            {/*                /!*        /!*</div>*!/*!/*/}
            {/*                /!*    </div>*!/*/}
            {/*                /!*</div>*!/*/}

            {/*                <div className="content md:mt-8">*/}
            {/*                    <div*/}
            {/*                        className="grid lg:grid-cols-12 grid-cols-1 md:text-start text-center justify-center">*/}
            {/*                        <div className="lg:col-start-2 lg:col-span-10">*/}
            {/*                            <div className="grid md:grid-cols-2 grid-cols-1 items-center">*/}
            {/*                                <div className="mt-8">*/}
            {/*                                    <div className="section-title text-md-start">*/}
            {/*                                        <h6 className="text-white/50 text-lg font-semibold dark:text-main">Our*/}
            {/*                                            goal</h6>*/}
            {/*                                        <h3 className="md:text-3xl text-2xl md:leading-normal leading-normal font-semibold text-white mt-2">Goal*/}
            {/*                                            is to provide the best<br/>*/}
            {/*                                            Experience </h3>*/}
            {/*                                    </div>*/}
            {/*                                </div>*/}

            {/*                                <div className="mt-8">*/}
            {/*                                    <div className="section-title text-md-start">*/}
            {/*                                        <p className="text-white/50 max-w-xl mx-auto mb-2">Start working*/}
            {/*                                            with Technex that can provide everything you need to generate*/}
            {/*                                            awareness, drive traffic, connect.</p>*/}

            {/*                                    </div>*/}
            {/*                                </div>*/}
            {/*                            </div>*/}
            {/*                        </div>*/}
            {/*                    </div>*/}
            {/*                </div>*/}
            {/*            </div>*/}
            {/*        </div>*/}
            {/*    </div>*/}

            {/*    <div*/}
            {/*        className="absolute bottom-0 start-0 end-0 sm:h-2/3 h-4/5 bg-gradient-to-b from-main to-main-gradient dark:from-secondary dark:to-secondary-hover"></div>*/}
            {/*</section>*/}

        </>
    )
}