"use client";
import {useForm} from "react-hook-form";
import {useState} from "react";
import Swal from "sweetalert2";
import {ApiConfig, handleApiRequest} from "@/app/services/apiConfig";
import {useTranslations} from "next-intl";

export const CareersForm = () => {
    const t = useTranslations("careers");
    const {
        register,
        handleSubmit,
        formState: {errors},
        reset,
    } = useForm();
    const [loading, setLoading] = useState(false); // Loading state

    const onSubmit = async (data) => {
        if (!data.resume[0]) {
            Swal.fire({
                icon: "error",
                title: "Error",
                text: "Please upload your resume",
            });
            return;
        }

        const formData = new FormData();
        formData.append("name", data.name);
        formData.append("email", data.email);
        formData.append("phone", data.number);
        formData.append("job_title", data.subject);
        formData.append("message", data.comments || ""); // Optional field
        formData.append("cv", data.resume[0]);

        setLoading(true); // Start loading
        handleApiRequest(
            ApiConfig.endpoints.submitCareer,
            "careers",
            "POST",
            formData,
            true,
            "client"
        ).then(() => {
            Swal.fire({
                icon: "success",
                title: "Success",
                text: "Your application has been submitted successfully!",
            });

            reset();
        }).catch((error) => {
            console.error("Error submitting form", error);

            Swal.fire({
                icon: "error",
                title: "Submission Failed",
                text: "There was an error submitting your application. Please try again.",
            });
        }).finally(
            () => setLoading(false)
        )
        // try {
        //     const response = await handleApiRequest(
        //         ApiConfig.endpoints.submitCareer,
        //         "careers",
        //         "POST",
        //         formData,
        //         true
        //     );
        //     console.log(response);
        //
        //     Swal.fire({
        //         icon: "success",
        //         title: "Success",
        //         text: "Your application has been submitted successfully!",
        //     });
        //
        //     reset(); // Reset the form after successful submission
        // } catch (error) {
        //     console.error("Error submitting form", error);
        //
        //     Swal.fire({
        //         icon: "error",
        //         title: "Submission Failed",
        //         text: "There was an error submitting your application. Please try again.",
        //     });
        // } finally {
        //     setLoading(false); // Stop loading
        // }
    };

    return (
        <div>
            <form onSubmit={handleSubmit(onSubmit)}>
                <div className="grid lg:grid-cols-12 gap-6">
                    {/* Name */}
                    <div className="lg:col-span-6">
                        <div className="text-start">
                            <label htmlFor="name" className="font-semibold">
                                {t("yourName")}
                            </label>
                            <input
                                {...register("name", {required: t("nameIsRequired")})}
                                id="name"
                                type="text"
                                className={`form-input mt-3 w-full py-2 px-3 h-10 bg-transparent dark:bg-slate-900 dark:text-slate-200 rounded outline-none border ${
                                    errors.name
                                        ? "border-red-500 focus:border-red-500"
                                        : "border-gray-200 focus:border-main dark:border-gray-800 dark:focus:border-main"
                                } focus:ring-0`}
                                placeholder={t("name")}
                            />
                            {errors.name && (
                                <span className="text-red-600">{errors.name.message}</span>
                            )}
                        </div>
                    </div>

                    {/* Email */}
                    <div className="lg:col-span-6">
                        <div className="text-start">
                            <label htmlFor="email" className="font-semibold">
                                {t("yourEmail")}
                            </label>
                            <input
                                {...register("email", {
                                    required: t("Email is required"),
                                    pattern: {
                                        value: /^\S+@\S+$/i,
                                        message: "Invalid email address",
                                    },
                                })}
                                id="email"
                                type="email"
                                className={`form-input mt-3 w-full py-2 px-3 h-10 bg-transparent dark:bg-slate-900 dark:text-slate-200 rounded outline-none border ${
                                    errors.email
                                        ? "border-red-500 focus:border-red-500"
                                        : "border-gray-200 focus:border-main dark:border-gray-800 dark:focus:border-main"
                                } focus:ring-0`}
                                placeholder={t("email")}
                            />
                            {errors.email && (
                                <span className="text-red-600">{errors.email.message}</span>
                            )}
                        </div>
                    </div>

                    {/* Phone Number */}
                    <div className="lg:col-span-6">
                        <div className="text-start">
                            <label htmlFor="phonenumber" className="font-semibold">
                                {t("phoneNo")}
                            </label>
                            <input
                                {...register("number", {required: t("Phone number is required")})}
                                id="phonenumber"
                                type="text"
                                className={`form-input mt-3 w-full py-2 px-3 h-10 bg-transparent dark:bg-slate-900 dark:text-slate-200 rounded outline-none border ${
                                    errors.number
                                        ? "border-red-500 focus:border-red-500"
                                        : "border-gray-200 focus:border-main dark:border-gray-800 dark:focus:border-main"
                                } focus:ring-0`}
                                placeholder={t("phoneNo")}
                            />
                            {errors.number && (
                                <span className="text-red-600">{errors.number.message}</span>
                            )}
                        </div>
                    </div>

                    {/* Job Title */}
                    <div className="lg:col-span-6">
                        <div className="text-start">
                            <label htmlFor="subject" className="font-semibold">
                                {t("jobTitle")}
                            </label>
                            <input
                                {...register("subject", {required: t("Job title is required")})}
                                id="subject"
                                type="text"
                                className={`form-input mt-3 w-full py-2 px-3 h-10 bg-transparent dark:bg-slate-900 dark:text-slate-200 rounded outline-none border ${
                                    errors.subject
                                        ? "border-red-500 focus:border-red-500"
                                        : "border-gray-200 focus:border-main dark:border-gray-800 dark:focus:border-main"
                                } focus:ring-0`}
                                placeholder={t("jobTitle")}
                            />
                            {errors.subject && (
                                <span className="text-red-600">{errors.subject.message}</span>
                            )}
                        </div>
                    </div>

                    {/* Comments */}
                    <div className="lg:col-span-12">
                        <div className="text-start">
                            <label htmlFor="comments" className="font-semibold">
                                {t("message")}
                            </label>
                            <textarea
                                {...register("comments")}
                                id="comments"
                                className="form-input mt-3 w-full py-2 px-3 h-28 bg-transparent dark:bg-slate-900 dark:text-slate-200 rounded outline-none border border-gray-200 focus:border-main dark:border-gray-800 dark:focus:border-main focus:ring-0"
                                placeholder={t("message")}
                            ></textarea>
                        </div>
                    </div>

                    {/* Resume Upload */}
                    <div className="lg:col-span-12">
                        <label className="font-semibold" htmlFor="resume">
                            {t("uploadYourResume")}
                        </label>
                        <input
                            {...register("resume", {required: t("Resume is required")})}
                            className={`form-input mt-3 w-full py-2 px-3 h-10 bg-transparent dark:bg-slate-900 dark:text-slate-200 rounded outline-none border ${
                                errors.resume
                                    ? "border-red-500 focus:border-red-500"
                                    : "border-gray-200 focus:border-main dark:border-gray-800 dark:focus:border-main"
                            } focus:ring-0`}
                            id="resume"
                            type="file"
                        />
                        {errors.resume && (
                            <span className="text-red-600">{errors.resume.message}</span>
                        )}
                    </div>
                </div>

                <button
                    id="send"
                    name="send"
                    type="submit"
                    disabled={loading} // Disable button during loading
                    className={`py-2 px-5 inline-block font-semibold tracking-wide border align-middle duration-500 text-base text-center bg-main hover:bg-main-hover border-main hover:border-main-hover text-white rounded-md mt-4 ${
                        loading ? "cursor-not-allowed opacity-50" : ""
                    }`}
                >
                    {loading ? t("sending") : t("send")}
                </button>
            </form>
        </div>
    );
};
