import React from 'react'
import {CareersForm} from "@/app/(pages)/Careers/components/careersForm";
import {ApiConfig, handleApiRequest} from "@/app/services/apiConfig";
import {getTranslations} from "next-intl/server";

export const metadata = {
    title: "Careers - Egypco pharma website",
    description: "Apply for a job at Egypco pharma",
};
export default async function Careers() {
    const careers = await handleApiRequest(ApiConfig.endpoints.getCareersPage);
    const t = await getTranslations("careers")
    return (
        <>

            <section className="relative table w-full py-36 lg:py-44 bg-no-repeat bg-center bg-cover"
                     style={{backgroundImage: `url(${careers?.page_hero?.background_image || '/images/careers.jpg'})`}}>
                <div className="absolute inset-0 bg-black opacity-80"></div>
                <div className="container relative">
                    <div className="grid grid-cols-1 pb-8 text-center mt-12">
                        <h3 className="mb-4 md:text-4xl text-3xl md:leading-normal leading-normal font-medium text-white">{careers?.page_hero?.name || t("careers")}</h3>

                        <ul className="list-none">
                            <li className="inline-flex items-center text-slate-400 me-3"><span
                                className="text-white ps-1">{careers?.page_hero?.slogan || t("applyHere,WeWillContactYouSoon")}</span>
                            </li>
                        </ul>
                    </div>
                </div>
            </section>
            <div className="relative">
                <div
                    className="shape absolute sm:-bottom-px -bottom-[2px] start-0 end-0 overflow-hidden text-white dark:text-slate-900">
                    <svg className="w-full h-auto scale-[2.0] origin-top" viewBox="0 0 2880 48" fill="none"
                         xmlns="http://www.w3.org/2000/svg">
                        <path d="M0 48H1437.5H2880V0H2160C1442.5 52 720 0 720 0H0V48Z" fill="currentColor"></path>
                    </svg>
                </div>
            </div>
            <section className="relative md:py-24 py-16 px-10 lg:px-0">
                <div className="container relative">
                    <div className="grid lg:grid-cols-12 grid-cols-1" id="reserve-form">
                        <div className="lg:col-start-2 lg:col-span-10">
                            <div className="rounded-md shadow dark:shadow-gray-800 bg-white dark:bg-slate-900 p-6">
                                <CareersForm/>
                            </div>
                        </div>
                    </div>
                </div>
            </section>
        </>
    )
}