import React from "react"
import Link from "next/link"
import Image from "next/image"
import {ContactUsForm} from "@/app/(pages)/Contact-us/components/contactUsForm";
import {ApiConfig, handleApiRequest} from "@/app/services/apiConfig";
import {FiPhone} from "react-icons/fi";
import {FaRegEnvelope} from "react-icons/fa";
import {RiMapPinLine} from "react-icons/ri";
import {getTranslations} from "next-intl/server";

export const metadata = {
    title: "Contact us - Egypco pharma website",
    description: "Contact us for more information",
};
export default async function ContactOne() {
    const contactUs = await handleApiRequest(ApiConfig.endpoints.getContactUsPage);
    const t = await getTranslations("contactUs")
    const contactData = [
        {
            icon: FiPhone,
            title: t("phone"),
            desc: "The phrasal sequence of the is now so that many campaign and benefit",
            contact: contactUs?.contact_info?.phone || "-",
            href: contactUs?.contact_info?.phone ? `tel:${contactUs?.contact_info?.phone}` : "#"
        },
        {
            icon: FaRegEnvelope,
            title: t("email"),
            desc: "The phrasal sequence of the is now so that many campaign and benefit",
            contact: contactUs?.contact_info?.email || "-",
            href: contactUs?.contact_info?.email ? `mailto:${contactUs?.contact_info?.email}` : "#"
        },
        {
            icon: RiMapPinLine,
            title: t("location"),
            desc: "The phrasal sequence of the is now so that many campaign and benefit",
            contact: t("viewOnGoogleMaps"),
            href: contactUs?.contact_info?.address_link || "#"
        }
    ]
    return (
        <>

            <section className="relative table w-full py-36  bg-center bg-no-repeat bg-cover "
                     style={{backgroundImage: `url(${contactUs?.page_hero?.background_image || '/images/company/aboutus.jpg'})`}}>
                <div className="absolute inset-0 bg-black opacity-75"></div>
                <div className="container relative">
                    <div className="grid grid-cols-1 pb-8 text-center mt-10">
                        <h3 className="md:text-4xl text-3xl md:leading-normal tracking-wide leading-normal font-medium text-white">{contactUs?.page_hero?.slogan || "Contact us"}</h3>

                    </div>

                </div>

            </section>
            <div className="relative">

                <div
                    className="shape absolute sm:-bottom-px -bottom-[2px] start-0 end-0 overflow-hidden z-1 text-white dark:text-slate-900">
                    <svg className="w-full h-auto scale-[2.0] origin-top" viewBox="0 0 2880 48" fill="none"
                         xmlns="http://www.w3.org/2000/svg">
                        <path d="M0 48H1437.5H2880V0H2160C1442.5 52 720 0 720 0H0V48Z" fill="currentColor"></path>
                    </svg>
                </div>
            </div>

            <section className="relative md:py-24 py-16 px-10 lg:px-0">
                <div className="container relative">
                    <div className="grid grid-cols-1 lg:grid-cols-3 md:grid-cols-2 gap-[30px]">
                        {contactData.map((item, index) => {
                            let Icons = item.icon
                            return (
                                <div key={index} className="text-center px-6 mt-6">
                                    <div
                                        className="w-20 h-20 bg-main/5 text-main rounded-xl text-3xl flex align-middle justify-center items-center shadow-sm dark:shadow-gray-800 mx-auto">
                                        <Icons className="w-7 h-7"/>
                                    </div>

                                    <div className="content mt-7">
                                        <h5 className="title h5 text-xl font-medium">{item.title}</h5>
                                        <div className="mt-5">
                                            <Link href={item.href}
                                                  target={'_blank'}
                                                  className="relative inline-block font-semibold tracking-wide align-middle text-base text-center border-none after:content-[''] after:absolute after:h-px after:w-0 hover:after:w-full after:end-0 hover:after:end-auto after:bottom-0 after:start-0 after:duration-500 text-main hover:text-main after:bg-main duration-500">{item.contact}</Link>
                                        </div>
                                    </div>
                                </div>
                            )
                        })}

                    </div>
                </div>

                <div className="container relative md:mt-24 mt-16">
                    <div className="grid md:grid-cols-12 grid-cols-1 items-center gap-[30px]">
                        <div className="lg:col-span-7 md:col-span-6">
                            <Image width={0} height={0} sizes="100vw" style={{width: "100%", height: "auto"}}
                                   unoptimized={true}
                                   src={contactUs?.contact_info?.form_side_image || "/images/contact.svg"} alt=""/>
                        </div>
                        <div className="lg:col-span-5 md:col-span-6">
                            <div className="lg:ms-5">
                                <div className="bg-white dark:bg-slate-900 rounded-md shadow dark:shadow-gray-800 p-6">
                                    <h3 className="mb-6 text-2xl leading-normal font-medium">{t("getInTouch")}</h3>
                                    {/*<div className={'text-center mb-6'}>*/}
                                    {/*    <SocialMedia isLight={false}/>*/}
                                    {/*</div>*/}
                                    {/*<h3 className="mb-6 text-base leading-normal text-center font-bold uppercase">Or</h3>*/}
                                    <ContactUsForm/>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </section>
            {contactUs?.contact_info?.map_iframe_link && <div className="container-fluid relative">
                <div className="grid grid-cols-1">
                    <div className="w-full leading-[0] border-0">
                        {/*<iframe*/}
                        {/*    src={contactUs?.contact_info?.map_iframe_link}*/}
                        {/*     height="450" allowFullScreen loading="lazy"*/}
                        {/*    className={"w-full h-[500px]"}*/}
                        {/*    referrerPolicy="no-referrer-when-downgrade"></iframe>*/}
                        <iframe title='google'
                                loading="lazy"
                                src={contactUs?.contact_info?.map_iframe_link}
                                style={{border: 0}} className="w-full h-[500px]" allowFullScreen></iframe>
                    </div>
                </div>
            </div>}

        </>
    )
}