import Link from "next/link";
import Image from "next/image";
import {FaArrowRight} from "react-icons/fa";
import {ApiConfig, handleApiRequest} from "@/app/services/apiConfig";
import {getTranslations} from "next-intl/server";

export const metadata = {
    title: "News - Egypco pharma website",
    description: "See our latest news and blogs",
};
export default async function News() {
    const newsPages = await handleApiRequest(ApiConfig.endpoints.newsPage);
    const allNews = await handleApiRequest(ApiConfig.endpoints.getNews);
    const t = await getTranslations("news")
    return (
        <>

            <section className="relative table w-full py-32 lg:py-36 bg-center bg-no-repeat bg-cover"
                     style={{backgroundImage: `url(${newsPages?.page_hero?.background_image || '/images/helpcenter.jpg'})`}}>
                <div className="absolute inset-0 bg-black opacity-80"></div>
                <div className="container relative">
                    <div className="grid grid-cols-1 pb-8 text-center mt-10">
                        <h3 className="md:text-4xl text-3xl md:leading-normal leading-normal font-medium text-white">{newsPages?.page_hero?.slogan || t("news")}</h3>
                    </div>
                </div>
            </section>
            <div className="relative">
                <div
                    className="shape absolute sm:-bottom-px -bottom-[2px] start-0 end-0 overflow-hidden z-1 text-white dark:text-slate-900">
                    <svg className="w-full h-auto scale-[2.0] origin-top" viewBox="0 0 2880 48" fill="none"
                         xmlns="http://www.w3.org/2000/svg">
                        <path d="M0 48H1437.5H2880V0H2160C1442.5 52 720 0 720 0H0V48Z" fill="currentColor"></path>
                    </svg>
                </div>
            </div>

            <section className="relative md:py-24 py-16">
                <div className="container relative">
                    <div className="grid grid-cols-1 lg:grid-cols-3 md:grid-cols-2 gap-[30px]">
                        {allNews?.data?.map((item, index) => {
                            return (
                                <div key={index}
                                     className="blog relative rounded-md shadow dark:shadow-gray-800 overflow-hidden">
                                    <Image src={item.mainImage} width={0} height={0} sizes='100vw'
                                           unoptimized={true}
                                           style={{width: "100%", height: "auto"}} alt=""/>

                                    <div className="content p-6">
                                        <Link href={`/News/New-details/${item.id}`}
                                              className="title h5 text-lg font-medium hover:text-main duration-500 ease-in-out">{item.title}</Link>
                                        <p className="text-slate-400 mt-3">{item.subDescription}</p>

                                        <div className="mt-4">
                                            <Link href={`/News/New-details/${item.id}`}
                                                  className="relative inline-flex items-center font-normal tracking-wide align-middle text-base text-center border-none after:content-[''] after:absolute after:h-px after:w-0 hover:after:w-full after:end-0 hover:after:end-auto after:bottom-0 after:start-0 after:duration-500 hover:text-main after:bg-main duration-500">Read
                                                More <FaArrowRight className="ms-2 text-[10px]"/></Link>
                                        </div>
                                    </div>
                                </div>
                            )
                        })}
                    </div>
                </div>
            </section>
        </>
    )
}