"use client"
import ProductCard from "@/app/components/products/productCard";
import {MdKeyboardArrowRight, MdOutlineKeyboardArrowLeft} from "react-icons/md";
import {ApiConfig, handleApiRequest} from "@/app/services/apiConfig";
import {useEffect, useState} from "react";
import Loading from "@/app/loading";
import Image from "next/image";
import * as Icon from "react-feather";

export const AllProducts = ({productType, categories}) => {
    const [selectedCategories, setSelectedCategories] = useState(null);
    const [loading, setLoading] = useState(true);
    const [productData, setProductData] = useState([]);
    const [page, setPage] = useState(1);
    const [pageSize] = useState(200);
    const [totalPages, setTotalPages] = useState(1);
    const [searchTerm, setSearchTerm] = useState('');

    // const debouncedSearchTerm = useDebounce(searchTerm, 500);


    function getProducts() {
        setLoading(true)
        let url = ''
        if (selectedCategories) {
            selectedCategories.map((item) => {
                url += `&${item.category}=${item.id.join(',')}`
            })
        }
        url = url
            ? `${ApiConfig.endpoints.getProducts}?page=${page}&posts_per_page=${pageSize}${url}&type=${productType?.toLowerCase() === "human" ? 1 : 0}`
            : `${ApiConfig.endpoints.getProducts}?page=${page}&posts_per_page=${pageSize}&type=${productType?.toLowerCase() === "human" ? 1 : 0}`;

        if (searchTerm) {
            url += `&search=${searchTerm}`;
        }

        handleApiRequest(url, "products", "GET", null, false, "client").then((data) => {
            setProductData(data);
            setTotalPages(data.totalPages);
        }).finally(
            () => setLoading(false)
        )
    }

    useEffect(() => {
        getProducts()
    }, []);
    const handleRadioChange = (value) => {
        setSelectedCategories((prevSelectedCategories) => {
            if (selectedCategories?.find((selected) => selected.category === value.category && selected.id.includes(value.id))) {
                return prevSelectedCategories.map((item) => {
                    if (item.category === value.category) {
                        item.id = item.id.filter((id) => id !== value.id)
                    }
                    return item
                })
            }
            const selectedCats = [...(prevSelectedCategories || [])];
            const selected = selectedCats.find((item) => item.category === value.category);

            if (selected) {
                selected.id.push(value.id);
            } else {
                selectedCats.push({category: value.category, id: [value.id]});
            }
            console.log(selectedCats)
            return selectedCats;
        });
    };
    const handlePageChange = (newPage) => {
        setPage(newPage);
    };
    return (
        <>{loading ? <Loading/> :
            <div className="container">
                <div className="grid md:grid-cols-12 grid-cols-1 gap-[30px]">
                    <div className="lg:col-span-4 md:col-span-6 relative mb-8">
                        <div
                            className="shadow  dark:shadow-gray-800 p-6 rounded-md bg-white dark:bg-slate-900 sticky top-20">
                            <form className={""}>
                                <div className="grid grid-cols-1 gap-3 max-h-[calc(100vh-200px)] overflow-auto">
                                    <div>
                                        <label htmlFor="searchname" className="hidden font-semibold"></label>
                                        <div className="relative">
                                            <Icon.Search className="size-4 absolute top-3 start-3"></Icon.Search>

                                            <input name="search" id="searchname" type="text"
                                                   className="form-input w-full py-2 px-3 h-10 ps-9 bg-transparent dark:bg-slate-900 dark:text-slate-200 rounded outline-none border border-gray-200 focus:border-main dark:border-gray-800 dark:focus:border-main focus:ring-0"
                                                   placeholder="Search"
                                                   value={searchTerm}
                                                   onChange={(e) => setSearchTerm(e.target.value)}
                                            />
                                        </div>
                                    </div>
                                    {Object?.keys(categories?.data || {})?.map((data, index) => {
                                        return (
                                            <div key={index}>
                                                {categories?.data[data]?.length > 0 && <label
                                                    className="font-semibold">{data.replace('_', " ")}</label>}
                                                {categories?.data[data]?.map((item, index) => {
                                                    return (
                                                        <div className="block mt-2" key={index}>
                                                            <div>
                                                                <label className="inline-flex items-center">
                                                                    <input type="checkbox"
                                                                           className="form-radio border-gray-200 dark:border-gray-800 text-main focus:border-indigo-300 focus:ring focus:ring-offset-0 focus:ring-indigo-200 focus:ring-opacity-50 me-2"
                                                                           name={`radio-${data}`
                                                                           }
                                                                           checked={selectedCategories?.find((selected) => selected.category === data && selected.id.includes(item.id))}
                                                                           value={item.id}
                                                                           onChange={() => handleRadioChange({
                                                                               category: data,
                                                                               id: item.id,
                                                                           })}
                                                                    />
                                                                    <span
                                                                        className="text-slate-400">{item.name}</span>
                                                                </label>
                                                            </div>
                                                        </div>
                                                    )
                                                })}
                                            </div>
                                        )
                                    })}


                                </div>
                            </form>
                            <div className="mt-2">
                                <input type="submit"
                                       className="py-2 px-5 sticky bottom-0 inline-block font-semibold tracking-wide border align-middle duration-500 text-base text-center bg-main hover:bg-main-hover border-main hover:border-main-hover text-white rounded-md w-full"
                                       value="Apply Filter"
                                       onClick={() => getProducts()}
                                />
                            </div>
                        </div>
                    </div>

                    <div className="lg:col-span-8 md:col-span-6">
                        <div className="grid md:grid-cols-12 grid-cols-1 items-center gap-[30px]">
                            <div className="lg:col-span-9 md:col-span-8">
                                <h3 className="text-xl leading-normal font-semibold">{productType}</h3>
                            </div>

                            {/*<div className="lg:col-span-3 md:col-span-4 md:text-end">*/}
                            {/*    <label className="font-semibold hidden"></label>*/}
                            {/*    <select*/}
                            {/*        className="form-select form-input w-full py-2 px-3 h-10 bg-transparent dark:bg-slate-900 dark:text-slate-200 rounded outline-none border border-gray-200 focus:border-main dark:border-gray-800 dark:focus:border-main focus:ring-0">*/}
                            {/*        <option defaultChecked>Sort by latest</option>*/}
                            {/*        <option>Sort by popularity</option>*/}
                            {/*        <option>Sort by rating</option>*/}
                            {/*        <option>Sort by price: low to high</option>*/}
                            {/*        <option>Sort by price: high to low</option>*/}
                            {/*    </select>*/}
                            {/*</div>*/}
                        </div>

                        <div className="grid lg:grid-cols-3 md:grid-cols-2 grid-cols-1 mt-8 gap-[30px]">

                            {productData?.data?.length === 0 ?

                                <div className={'col-span-3 flex flex-col justify-center items-center w-full'}
                                >
                                    <Image
                                        blurDataURL={'/images/no-result.jpg'}
                                        src={'/images/no-result.jpg'}
                                        alt={"No result"}
                                        height={0}
                                        width={0}
                                        sizes={"100vw"}
                                        className={"h-full w-1/3"}
                                    />
                                    <p className={'text-slate-300'}>
                                        No result found
                                    </p>
                                </div>
                                : productData?.data?.map((item, index) => {
                                    return (
                                        <ProductCard item={item} key={index} type={productType}/>
                                    )
                                })}
                        </div>

                        <div className="grid md:grid-cols-12 grid-cols-1 my-8">
                            <div className="md:col-span-12 text-center">
                                <nav aria-label="Page navigation example">
                                    <ul className="inline-flex items-center -space-x-px">
                                        <li>
                                            <button
                                                onClick={() => handlePageChange(page - 1)}
                                                disabled={page === 1}
                                                className="size-[40px] inline-flex justify-center items-center text-slate-400 bg-white dark:bg-slate-900 rounded-s-lg hover:text-white border border-gray-100 dark:border-gray-700 hover:border-main dark:hover:border-main hover:bg-main dark:hover:bg-main">
                                                <MdOutlineKeyboardArrowLeft
                                                    className="text-[20px] rtl:rotate-180 rtl:-mt-1"/>
                                            </button>
                                        </li>
                                        <li>
                                            {[...Array(totalPages)].map((_, index) => (
                                                <button
                                                    key={index}
                                                    onClick={() => handlePageChange(index + 1)}
                                                    className={`pagination-btn ${page === index + 1 ? 'z-10 size-[40px] inline-flex justify-center items-center text-white bg-main border border-main' : 'size-[40px] inline-flex justify-center items-center text-slate-400 hover:text-white bg-white dark:bg-slate-900 border border-gray-100 dark:border-gray-700 hover:border-main dark:hover:border-main hover:bg-main dark:hover:bg-main"'}`}
                                                >
                                                    {index + 1}
                                                </button>
                                            ))}
                                        </li>

                                        <li>
                                            <button
                                                onClick={() => handlePageChange(page + 1)}
                                                disabled={page === totalPages}
                                                className="size-[40px] inline-flex justify-center items-center text-slate-400 bg-white dark:bg-slate-900 rounded-e-lg hover:text-white border border-gray-100 dark:border-gray-700 hover:border-main dark:hover:border-main hover:bg-main dark:hover:bg-main">
                                                <MdKeyboardArrowRight className="text-xl rtl:rotate-180 rtl:-mt-1"/>
                                            </button>
                                        </li>
                                    </ul>
                                </nav>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        }
        </>
    )
}