"use client"
import React, {useState} from 'react'
import Image from "next/image"
import dynamic from "next/dynamic"

const TinySlider = dynamic(() => import("tiny-slider-react"), {ssr: false})
import "tiny-slider/dist/tiny-slider.css";

export default function ProductDetail({productDetails}) {

    const settings = {
        container: '.tiny-single-item',
        items: 1,
        controls: false,
        mouseDrag: true,
        loop: true,
        rewind: true,
        autoplay: true,
        autoplayButtonOutput: false,
        autoplayTimeout: 3000,
        navPosition: "bottom",
        speed: 400,
        gutter: 16,
    }
    const [isOpenTab, setisOpen] = useState(0);

    const handleTabClick = (index) => {
        setisOpen(index);
    };

    return (
        <>
            <div className="grid md:grid-cols-12 grid-cols-1 gap-[30px] items-center">
                <div className="lg:col-span-5 md:col-span-6">
                    <div className="tiny-single-item">
                        <TinySlider settings={settings}>

                            <div className="tiny-slide">
                                <Image src={productDetails?.data?.mainImage} width={0} height={0} sizes='100vw'
                                       unoptimized={true}
                                       style={{width: "100%", height: "auto"}}
                                       className="rounded-md shadow dark:shadow-gray-800" alt=""/>
                            </div>

                        </TinySlider>
                    </div>
                </div>

                <div className="lg:col-span-7 md:col-span-6">
                    <div className="lg:ms-6">
                        <h5 className="text-4xl font-semibold">{productDetails?.data?.title || "-"}</h5>
                        {/*<div className="mt-2">*/}
                        {/*    <span className="text-slate-400 font-semibold me-1">$16USD <del*/}
                        {/*        className="text-red-600">$21USD</del></span>*/}

                        {/*    <ul className="list-none inline-block text-orange-400 space-x-1">*/}
                        {/*        <li className="inline"><i className="mdi mdi-star text-lg"></i></li>*/}
                        {/*        <li className="inline"><i className="mdi mdi-star text-lg"></i></li>*/}
                        {/*        <li className="inline"><i className="mdi mdi-star text-lg"></i></li>*/}
                        {/*        <li className="inline"><i className="mdi mdi-star text-lg"></i></li>*/}
                        {/*        <li className="inline"><i className="mdi mdi-star text-lg"></i></li>*/}
                        {/*        <li className="inline text-slate-400 font-semibold">4.8 (45)</li>*/}
                        {/*    </ul>*/}
                        {/*</div>*/}

                        {productDetails?.data?.activeIngredient?.length > 0 && <div className="mt-4 flex items-center gap-1 flex-wrap">
                            <h5 className="text-lg font-semibold">Active ingredients :</h5>
                            <p className="text-slate-400 "
                            >
                                {productDetails?.data?.activeIngredient.map((item) => item?.name).join(", ")}
                            </p>
                        </div>}
                        {productDetails?.data?.indications?.length > 0 && <div className="mt-4 flex items-center gap-1 flex-wrap">
                            <h5 className="text-lg font-semibold">Indication :</h5>
                            <p className="text-slate-400"
                            >
                                {productDetails?.data?.indications.map((item) => item?.name).join(", ")}
                            </p>
                        </div>}
                        {productDetails?.data?.dosageForm?.length > 0 && <div className="mt-4 flex items-center gap-1 flex-wrap">
                            <h5 className="text-lg font-semibold">Dosage Form :</h5>
                            <p className="text-slate-400"
                            >
                                {productDetails?.data?.dosageForm.map((item) => item?.name).join(", ")}
                            </p>
                        </div>}

                    </div>
                </div>
            </div>

            <div className="grid md:grid-cols-12 grid-cols-1 mt-10 gap-[30px]">
                <div className="lg:col-span-3 md:col-span-5">
                    <div className="sticky top-20">
                        <ul className="flex-column p-6 bg-white dark:bg-slate-900 shadow dark:shadow-gray-800 rounded-md"
                            id="myTab" data-tabs-toggle="#myTabContent" role="tablist">
                            <li role="presentation">
                                <button onClick={() => handleTabClick(0)}
                                        className={`${isOpenTab === 0 ? 'text-white bg-main hover:text-white' : ''} px-4 py-2 text-start font-semibold rounded-md w-full mt-3 hover:text-main transition-all duration-500 ease-in-out`}
                                        id="dashboard-tab" data-tabs-target="#dashboard" type="button" role="tab"
                                        aria-controls="dashboard" aria-selected="false">Description
                                </button>
                            </li>
                            {productDetails?.data?.pdfFile && <li role="presentation">
                                <button onClick={() => {
                                    window.open(productDetails?.data?.pdfFile?.url, '_blank')
                                }}
                                        className={`${isOpenTab === 1 ? 'text-white bg-main hover:text-white' : ''} px-4 py-2 text-start font-semibold rounded-md w-full mt-3 hover:text-main transition-all duration-500 ease-in-out`}
                                        id="dashboard-tab" data-tabs-target="#dashboard" type="button" role="tab"
                                        aria-controls="dashboard" aria-selected="false">Download PDF
                                </button>
                            </li>}

                        </ul>
                    </div>
                </div>

                <div className="lg:col-span-9 md:col-span-7">
                    <div id="" className=" p-6 bg-white dark:bg-slate-900 shadow dark:shadow-gray-800 rounded-md">
                        {isOpenTab === 0 ? <div className="myTabContent active" id="description" role="tabpanel"
                                                aria-labelledby="profile-tab">
                            <div className="mt-4">
                                <h5 className="text-lg font-semibold">Active ingredients</h5>
                                <div className="text-slate-400 mt-2"
                                     dangerouslySetInnerHTML={{__html: productDetails?.data?.activeIngredientDescription||""}}/>
                            </div>
                            <div className="mt-4">
                                <h5 className="text-lg font-semibold">Indication</h5>
                                <div className="text-slate-400 mt-2"
                                     dangerouslySetInnerHTML={{__html: productDetails?.data?.indicationDescription||""}}/>
                            </div>
                            <div className="mt-4">
                                <h5 className="text-lg font-semibold">Precaution</h5>
                                <div className="text-slate-400 mt-2"
                                     dangerouslySetInnerHTML={{__html: productDetails?.data?.precautionDescription||""}}/>
                            </div>

                        </div> : ""}

                        {/*{isOpenTab === 1 ?*/}
                        {/*    <div className="myTabContent " id="addinfo" role="tabpanel" aria-labelledby="addinfo-tab">*/}
                        {/*        <table className="w-full text-start">*/}
                        {/*            <tbody>*/}
                        {/*            <tr className="bg-white dark:bg-slate-900 border-b border-gray-100 dark:border-gray-700">*/}
                        {/*                <td className="font-semibold py-4" style={{width: '100px'}}>Color</td>*/}
                        {/*                <td className="text-slate-400 py-4">Red, White, Black, Orange</td>*/}
                        {/*            </tr>*/}

                        {/*            <tr className="bg-white dark:bg-slate-900 border-b border-gray-100 dark:border-gray-700">*/}
                        {/*                <td className="font-semibold py-4">Material</td>*/}
                        {/*                <td className="text-slate-400 py-4">Cotton</td>*/}
                        {/*            </tr>*/}

                        {/*            <tr className="bg-white dark:bg-slate-900 border-b border-gray-100 dark:border-gray-700">*/}
                        {/*                <td className="font-semibold py-4">Size</td>*/}
                        {/*                <td className="text-slate-400 py-4">S, M, L, XL, XXL</td>*/}
                        {/*            </tr>*/}
                        {/*            </tbody>*/}
                        {/*        </table>*/}
                        {/*    </div> : ""}*/}


                    </div>
                </div>
            </div>

        </>
    )
}