import Image from "next/image";
import React from "react";
import {ApiConfig, handleApiRequest} from "@/app/services/apiConfig";
import {getTranslations} from "next-intl/server";

export const metadata = {
    title: "Services - Egypco pharma website",
    description: "View our services",
};

export default async function Services() {
    const services = await handleApiRequest(ApiConfig.endpoints.services);
    const t = await getTranslations('services');
    return (
        <>

            <section className="relative table w-full py-36 lg:py-44 bg-no-repeat bg-center bg-cover"
                     style={{backgroundImage: `url(${services?.page_hero?.background_image || '/images/services.jpg'})`}}>

                <div className="absolute inset-0 bg-black opacity-75"></div>
                <div className="container relative">
                    <div className="grid grid-cols-1 pb-8 text-center mt-10">
                        <h5 className="text-white/50 text-lg font-medium">{services?.page_hero?.slogan || t("whatWeOffer?")}</h5>
                        <h3 className="mt-2 md:text-4xl text-3xl md:leading-normal leading-normal font-medium text-white">{services?.page_hero?.name || t("ourServices")}</h3>
                    </div>
                </div>
            </section>
            <div className="relative">
                <div
                    className="shape absolute sm:-bottom-px -bottom-[2px] start-0 end-0 overflow-hidden text-white dark:text-slate-900">
                    <svg className="w-full h-auto scale-[2.0] origin-top" viewBox="0 0 2880 48" fill="none"
                         xmlns="http://www.w3.org/2000/svg">
                        <path d="M0 48H1437.5H2880V0H2160C1442.5 52 720 0 720 0H0V48Z" fill="currentColor"></path>
                    </svg>
                </div>
            </div>
            {/*<section className="relative md:py-24 py-16 overflow-hidden px-10 lg:px-0">*/}
            {/*    <div className="container relative">*/}
            {/*        <div className="grid grid-cols-1 pb-8 text-center">*/}
            {/*            <h3 className="mb-6 md:text-3xl text-2xl md:leading-normal leading-normal font-semibold">Section*/}
            {/*                1</h3>*/}

            {/*            <p className="text-slate-400 max-w-xl mx-auto">enim veniam nostrud eiusmod sit aliquip sint ad*/}
            {/*                lorem consequat elit minim amet sit non ex exercitation deserunt est. sunt cupidatat*/}
            {/*                reprehenderit fugiat</p>*/}
            {/*        </div>*/}

            {/*        <div className="grid lg:grid-cols-4 md:grid-cols-2 grid-cols-1 mt-8 gap-[30px]">*/}
            {/*            <ServiceCard title={'Title 1'}*/}
            {/*                         description={'If the distribution of letters and words is random, the reader will not be distracted from making.'}*/}
            {/*                         icon={<MdAirplay/>}/>*/}

            {/*            <ServiceCard title={'Title 2'}*/}
            {/*                         description={'If the distribution of letters and words is random, the reader will not be distracted from making.'}*/}
            {/*                         icon={<MdApi/>} withMargin={true}/>*/}

            {/*            <ServiceCard title={'Title 3'}*/}
            {/*                         description={'If the distribution of letters and words is random, the reader will not be distracted from making.'}*/}
            {/*                         icon={<HiOutlineCog6Tooth/>}/>*/}

            {/*            <ServiceCard title={'Title 4'}*/}
            {/*                         description={'If the distribution of letters and words is random, the reader will not be distracted from making.'}*/}
            {/*                         icon={<FaRegComments/>} withMargin={true}/>*/}

            {/*        </div>*/}
            {/*    </div>*/}
            {/*</section>*/}
            <section className="relative md:py-24 py-16 bg-gray-50 dark:bg-slate-800 px-10 lg:px-0">
                {services.services.map((service, index) => {
                    if (index % 2 === 0) {
                        return (
                            <div className="container relative md:mt-24 mt-16" key={index}>
                                <div className="grid md:grid-cols-2 grid-cols-1 items-center mt-16 gap-[30px]">
                                    <div className="relative">
                                        <div className="md:me-10">
                                            <Image src={service?.image || "/images/about.jpg"} width={0} height={0}
                                                   sizes="100vw"
                                                   unoptimized={true}
                                                   style={{width: "100%", height: "auto"}} placeholder="blur"
                                                   blurDataURL="/images/about.jpg"
                                                   className="rounded-lg shadow-md dark:shadow-gray-800" alt=""/>
                                        </div>

                                    </div>

                                    <div className="lg:ms-8 mt-8 md:mt-0">
                                        <h4 className="mb-4 md:text-3xl text-2xl md:leading-normal leading-normal font-semibold">{service?.title}</h4>
                                        <div className="text-slate-400"
                                             dangerouslySetInnerHTML={{__html: service?.description || ""}}></div>


                                    </div>
                                </div>
                            </div>
                        )
                    } else {
                        return (
                            <div className="container relative md:mt-24 mt-16" key={index}>
                                <div className="grid md:grid-cols-2 grid-cols-1 items-center gap-[30px]">
                                    <div className="relative order-1 md:order-2">
                                        <Image src={service?.image || "/images/about2.jpg"} placeholder="blur"
                                               blurDataURL="/images/about2.jpg" width={0} height={0} sizes="100vw"
                                               unoptimized={true}
                                               style={{width: "100%", height: "auto"}}
                                               className="rounded-lg shadow-md dark:shadow-gray-800" alt=""/>
                                    </div>

                                    <div className="lg:me-8 order-2 md:order-1">
                                        <h4 className="mb-4 md:text-3xl text-2xl md:leading-normal leading-normal font-semibold">{service?.title || "Section 1"}</h4>
                                        <div className="text-slate-400"
                                             dangerouslySetInnerHTML={{__html: service?.description || ""}}></div>
                                        {/*<ul className="list-none text-slate-400 mt-4">*/}
                                        {/*    <li className="mb-1 flex items-center"><BsCheckCircle*/}
                                        {/*        className="text-main text-base me-2"/> Quality control and assurance*/}
                                        {/*    </li>*/}
                                        {/*    <li className="mb-1 flex items-center"><BsCheckCircle*/}
                                        {/*        className="text-main text-base me-2"/> Certifications and compliance*/}
                                        {/*    </li>*/}
                                        {/*    <li className="mb-1 flex items-center"><BsCheckCircle*/}
                                        {/*        className="text-main text-base me-2"/> Manufacturing and production*/}
                                        {/*    </li>*/}
                                        {/*</ul>*/}

                                    </div>
                                </div>
                            </div>
                        )
                    }
                })}
            </section>
            {/*<section className="relative table w-full py-36 lg:py-44 bg-no-repeat bg-center bg-cover px-10 lg:px-0">*/}
            {/*    <div className="container relative md:mt-24 mt-16">*/}
            {/*        <div className="grid md:grid-cols-2 grid-cols-1 items-center mt-10 gap-[30px]">*/}
            {/*            <div className="relative">*/}
            {/*                <Image src="/images/about3.jpg" width={0} height={0} sizes="100vw"*/}
            {/*                       style={{width: "100%", height: "auto"}}*/}
            {/*                       className="rounded-lg shadow-md dark:shadow-gray-800" alt=""/>*/}
            {/*                <div*/}
            {/*                    className="overflow-hidden absolute lg:size-[400px] size-[320px] bg-main/5 bottom-0 start-0 rotate-45 -z-1 rounded-3xl"></div>*/}
            {/*            </div>*/}

            {/*            <div className="lg:ms-8">*/}
            {/*                <div className="grid grid-cols-1 gap-[30px]">*/}
            {/*                    {hostingAbout.map((item, index) => {*/}
            {/*                        let Icons = item.icon*/}
            {/*                        return (*/}
            {/*                            <div key={index}*/}
            {/*                                 className="group flex items-center relative overflow-hidden p-6 rounded-md shadow dark:shadow-gray-800 bg-gray-50 dark:bg-slate-800 hover:bg-main dark:hover:bg-main transition-all duration-500 ease-in-out">*/}
            {/*                            <span*/}
            {/*                                className="text-main group-hover:text-white text-5xl font-semibold transition-all duration-500 ease-in-out">*/}
            {/*                                <Icons className="w-8 h-8"/>*/}
            {/*                            </span>*/}
            {/*                                <div className="flex-1 ms-3">*/}
            {/*                                    <h5 className="group-hover:text-white text-xl font-semibold transition-all duration-500 ease-in-out">{item.title}</h5>*/}
            {/*                                    <p className="text-slate-400 group-hover:text-white/50 transition-all duration-500 ease-in-out mt-2">{item.desc}</p>*/}
            {/*                                </div>*/}
            {/*                                <div*/}
            {/*                                    className="absolute start-1 top-5 text-dark/[0.03] dark:text-white/[0.03] text-8xl group-hover:text-white/[0.04] transition-all duration-500 ease-in-out">*/}
            {/*                                    <Icons className="w-20 h-20"/>*/}
            {/*                                </div>*/}
            {/*                            </div>*/}

            {/*                        )*/}
            {/*                    })}*/}
            {/*                </div>*/}
            {/*            </div>*/}
            {/*        </div>*/}
            {/*    </div>*/}
            {/*</section>*/}
        </>
    )
}