import React from "react";
import Link from "next/link";
import Image from "next/image";
import {MdKeyboardArrowRight} from "react-icons/md";
import SocialMedia from "@/app/components/socialMedia/socialMedia";
import {getTranslations} from "next-intl/server";

export default async function Footer({footer}) {
    const t = await getTranslations('footer')
    const footerCompany = [
        {
            liClass: "",
            route: "/About-us",
            title: t("aboutUs"),
        },
        {
            liClass: "mt-[10px]",
            route: "/Services",
            title: t("services"),
        },
        // {
        //     liClass: "mt-[10px]",
        //     route: "/Products/",
        //     title: "Products",
        // },
        {
            liClass: "mt-[10px]",
            route: "/News",
            title: t("news"),
        },
        {
            liClass: "mt-[10px]",
            route: "/Careers",
            title: t("careers"),
        },
        {
            route: "/Contact-us",
            title: t("contactUs"),
            liClass: "mt-[10px]",
        },

    ];
    return (
        <div>
            <footer
                className={`footer bg-dark-footer relative text-gray-200 dark:text-gray-200 px-10 lg:px-0`}>
                <div className='container relative'>
                    <div className='grid grid-cols-12'>
                        <div className='col-span-12'>
                            <div className='py-[60px] px-0'>
                                <div className='grid md:grid-cols-12 grid-cols-1 gap-[30px]'>
                                    <div className='lg:col-span-5 md:col-span-12'>
                                        <Link href='/#' className='text-[22px] focus:outline-none'>
                                            <Image
                                                unoptimized={true}
                                                src={footer?.company?.logo || '/images/egyco-logo.png'}
                                                width={90}
                                                height={100}
                                                layout="intrinsic"
                                                className='inline-block'
                                                alt=''
                                            />

                                        </Link>
                                        <div className='mt-6 text-gray-300'
                                             dangerouslySetInnerHTML={{__html: footer?.company?.description||""}}/>
                                        <SocialMedia links={{
                                            facebook: footer?.company?.facebook,
                                            email: footer?.company?.email,
                                            linkedin: footer?.company?.linkedin,
                                            instagram: footer?.company?.instagram,
                                        }}/>
                                    </div>
                                    <div className='lg:col-span-5 md:col-span-12'>
                                        <Link href='/#' className='text-[22px] focus:outline-none'>
                                            <Image
                                                src={footer?.factory?.logo || '/images/egyco-logo-factory.png'}
                                                unoptimized={true}
                                                width={210}
                                                height={64}
                                                className='inline-block'
                                                alt=''
                                            />

                                        </Link>
                                        <div className='mt-6 text-gray-300'
                                             dangerouslySetInnerHTML={{__html: footer?.factory?.description}}/>
                                        <SocialMedia links={{
                                            facebook: footer?.factory?.facebook,
                                            email: footer?.factory?.email,
                                            linkedin: footer?.factory?.linkedin,
                                            instagram: footer?.factory?.instagram,
                                        }}/>
                                    </div>
                                    <div className='lg:col-span-2 md:col-span-4 flex flex-col lg:items-center '>
                                        <h5 className='tracking-[1px] text-gray-100 font-semibold'>
                                            {t("company")}
                                        </h5>
                                        <ul className='list-none footer-list mt-6'>
                                            {footerCompany.map((data, index) => (
                                                <li key={index} className={data.liClass}>
                                                    <Link
                                                        href={data.route}
                                                        className='text-gray-300 hover:text-gray-400 duration-500 ease-in-out flex items-center'
                                                    >
                                                        <MdKeyboardArrowRight className='text-xl me-1'/>{" "}
                                                        {data.title}
                                                    </Link>
                                                </li>
                                            ))}
                                        </ul>
                                    </div>

                                    {/*<div className='lg:col-span-4 md:col-span-4'>*/}
                                    {/*    <h5 className='tracking-[1px] text-gray-100 font-semibold'>*/}
                                    {/*        Newsletter*/}
                                    {/*    </h5>*/}
                                    {/*    <p className='mt-6'>*/}
                                    {/*        Sign up and receive the latest tips via email.*/}
                                    {/*    </p>*/}
                                    {/*    <form>*/}
                                    {/*        <div className='grid grid-cols-1'>*/}
                                    {/*            <div className='foot-subscribe my-3'>*/}
                                    {/*                <label className='form-label'>*/}
                                    {/*                    Write your email{" "}*/}
                                    {/*                    <span className='text-red-600'>*</span>*/}
                                    {/*                </label>*/}
                                    {/*                <div className='form-icon relative mt-2'>*/}
                                    {/*                    <Icon.Mail className='size-4 absolute top-3 start-4'/>*/}
                                    {/*                    <input*/}
                                    {/*                        type='email'*/}
                                    {/*                        className='form-input ps-12 rounded w-full py-2 px-3 h-10 bg-gray-800 border-0 text-gray-100 focus:shadow-none focus:ring-0'*/}
                                    {/*                        placeholder='Email'*/}
                                    {/*                        name='email'*/}
                                    {/*                        required=''*/}
                                    {/*                    />*/}
                                    {/*                </div>*/}
                                    {/*            </div>*/}

                                    {/*            <button*/}
                                    {/*                type='submit'*/}
                                    {/*                id='submitsubscribe'*/}
                                    {/*                name='send'*/}
                                    {/*                className='py-2 px-5 inline-block font-semibold tracking-wide border align-middle duration-500 text-base text-center bg-main hover:bg-indigo-700 border-main hover:border-indigo-700 text-white rounded-md'*/}
                                    {/*            >*/}
                                    {/*                Subscribe*/}
                                    {/*            </button>*/}
                                    {/*        </div>*/}
                                    {/*    </form>*/}
                                    {/*</div>*/}
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <div className='py-[30px] px-0 border-t border-slate-800 '>
                    <div className='container relative text-center'>
                        <div className='grid md:grid-cols-1 items-center'>
                            <div className='md:text-center text-center'>
                                <p className='mb-0'>
                                    © {new Date().getFullYear()} Egypco. {t("design&developed")}{" "}
                                    <Link
                                        href='#'
                                        target='_blank'
                                        className='text-reset'
                                    >
                                        Technex
                                    </Link>
                                    .
                                </p>
                            </div>
                        </div>
                    </div>
                </div>
            </footer>
        </div>
    );
}
