"use client";
import {useState, useEffect} from "react";
import Link from "next/link";
import Image from "next/image";
import {usePathname} from "next/navigation";
import {LanguageSwitcher} from "@/app/components/languageSwitcherSelect";
import {useTranslations} from "next-intl";

export default function Navbar(props) {
    const t = useTranslations('nav')
    let {navJustify, logo} = props;
    let [isMenu, setIsMenu] = useState(false);
    let [menu, setMenu] = useState("");
    let pathname = usePathname();
    const [navClass, setNavClass] = useState("");


    useEffect(() => {
        setMenu(pathname);
        getNavClassName()

        function windowScroll() {
            const navbar = document.getElementById("topnav");
            if (
                document.body.scrollTop >= 50 ||
                document.documentElement.scrollTop >= 50
            ) {
                if (navbar !== null) {
                    navbar?.classList.add("nav-sticky");
                    setNavClass("nav-sticky")
                }
            } else {
                if (navbar !== null) {
                    navbar?.classList.remove("nav-sticky");
                    getNavClassName()
                }
            }
        }

        window.addEventListener("scroll", windowScroll);
        window.scrollTo(0, 0);
        return () => {
            window.removeEventListener("scroll", windowScroll);
        };
    }, [setMenu, pathname]);


    const toggleMenu = () => {
        setIsMenu(!isMenu);
        if (document.getElementById("navigation")) {
            const anchorArray = Array.from(
                document.getElementById("navigation").getElementsByTagName("a")
            );
            anchorArray.forEach((element) => {
                element.addEventListener("click", (elem) => {
                    const target = elem.target.getAttribute("href");
                    if (target !== "") {
                        if (elem.target.nextElementSibling) {
                            var submenu = elem.target.nextElementSibling.nextElementSibling;
                            submenu.classList.toggle("open");
                        }
                    }
                });
            });
        }
    };

    function getNavClassName() {
        console.log(menu.includes("/News"))
        if (['/Contact-us', '/Services', '/Careers', '/News', '/About-us'].includes("/" + pathname.split("/")[1])) setNavClass('nav-light')
        else setNavClass('')
    }

    return (
        <nav
            id='topnav'
            className={`defaultscroll ${
                navClass === "nav-light"
                    ? ""
                    : navClass === "nav-sticky"
                        ? "bg-white dark:bg-slate-900"
                        : navClass === "hidden" ?
                            "hidden" : ""
            }`}
        >
            <div className='container relative'>
                <Link className='logo' href='/'>
                    <Image
                        unoptimized={true}
                        src={logo || ""}
                        width={60}
                        height={100}
                        className='inline-block'
                        alt=''
                    />

                </Link>
                <div className='menu-extras'>
                    <div className='menu-item'>
                        <Link
                            href='#'
                            className={`navbar-toggle ${isMenu ? "open" : ""}`}
                            id='isToggle'
                            onClick={() => toggleMenu()}
                        >
                            <div className='lines'>
                                <span></span>
                                <span></span>
                                <span></span>
                            </div>
                        </Link>
                    </div>
                </div>
                <div id='navigation' style={{display: isMenu ? "block" : "none"}}>
                    <ul className={`navigation-menu ${navClass} ${navJustify}`}>
                        <li className={menu === "/" || "" ? "active" : ""}>
                            <Link href='/' className='sub-menu-item'>
                                {t("home")}
                            </Link>
                        </li>
                        <li className={`${["/About-us", "/Services", "/News", "/Careers", "/New-details"].includes("/" + menu.split("/")[1]) ? "active" : ""} has-submenu parent-menu-item`}>
                            <Link href="#"> {t("knowUs")}</Link><span className="menu-arrow"></span>
                            <ul className="submenu">
                                <li className={menu === "/About-us" || "" ? "active" : ""}><Link href="/About-us"
                                                                                                 className="sub-menu-item">{t("aboutUs")}</Link>
                                </li>
                                <li className={menu === "/Services" || "" ? "active" : ""}><Link href="/Services"
                                                                                                 className="sub-menu-item">{t("services")}</Link>
                                </li>
                                <li className={menu?.includes("/News") || "" ? "active" : ""}><Link href="/News"
                                                                                                    className="sub-menu-item">{t("news")}</Link>
                                </li>
                                <li className={menu === "/Careers" || "" ? "active" : ""}><Link href="/Careers"
                                                                                                className="sub-menu-item">{t("career")}</Link>
                                </li>
                            </ul>
                        </li>

                        <li className={`${["/Products"].includes("/" + menu.split("/")[1]) ? "active" : ""} has-submenu parent-menu-item`}>
                            <Link href="#">{t("products")}</Link><span className="menu-arrow"></span>
                            <ul className="submenu">
                                <li className={menu === "/Products/Human" || "" ? "active" : ""}><Link
                                    href="/Products/Human"
                                    className="sub-menu-item">{t("human")}</Link>
                                </li>
                                <li className={menu?.toLowerCase().includes("/Products/Veterinary"?.toLowerCase()) || "" ? "active" : ""}>
                                    <Link
                                        href="/Products/Veterinary"
                                        className="sub-menu-item">{t("veterinary")}</Link>
                                </li>
                            </ul>
                        </li>

                        <li className={menu?.includes("/Contact-us") || "" ? "active" : ""}>
                            <Link href='/Contact-us' className='sub-menu-item'>
                                {t("contactUs")}
                            </Link>
                        </li>
                    </ul>
                    <LanguageSwitcher navClass={navClass}/>
                </div>

            </div>
        </nav>
    );
}
