import "../app/assets/scss/tailwind.scss";
import "./assets/css/material.css";
import {
    Nunito,
    Work_Sans,
    EB_Garamond,
    Kaushan_Script,
    Alex_Brush,
} from "next/font/google";
import StoreProvider from "@/app/StoreProvider";
import Head from "next/head";
import {NextIntlClientProvider} from 'next-intl';
import {getLocale, getMessages} from 'next-intl/server';

const nunito = Nunito({
    subsets: ["latin"],
    variable: "--font-nunito",
    weight: ["300", "400", "500", "600", "700"],
    display: "swap",
});
const work_sans = Work_Sans({
    subsets: ["latin"],
    variable: "--font-work-sans",
    weight: ["300", "400", "500", "600", "700"],
    display: "swap",
});
const eb_garamond = EB_Garamond({
    subsets: ["latin"],
    variable: "--font-eb-garamond",
    weight: ["400"],
    display: "swap",
});

const kaushan = Kaushan_Script({
    subsets: ["latin"],
    variable: "--font-kaushan",
    weight: ["400"],
    display: "swap",
});

const alex = Alex_Brush({
    subsets: ["latin"],
    variable: "--font-alex",
    weight: ["400"],
    display: "swap",
});

export const metadata = {
    title: "Technex - Egypco pharma website",
    description: "Technex - Egypco pharma website",
};

export default async function RootLayout({children}) {
    const locale = await getLocale();
    const messages = await getMessages();
    return (
        <html lang={locale.lang} dir={locale.lang === "ar" ? "rtl" : "ltr"}>
        <Head>
            <link rel="shortcut icon" href="/images/favicon.ico"/>
        </Head>
        <body
            className={`${nunito.variable} ${work_sans.variable} ${eb_garamond.variable} ${kaushan.variable} ${alex.variable} font-nunito text-base text-black dark:text-white dark:bg-slate-900`}
        >

        <main className={'md:pt-0 pt-10'}>
            <StoreProvider>
                <NextIntlClientProvider messages={messages}>
                    {children}
                </NextIntlClientProvider>
            </StoreProvider>
        </main>

        </body>
        </html>
    );
}
