import {getLocale} from "next-intl/server";

const baseUrl =
    process.env.NODE_ENV === "development"
        ? process.env.NEXT_PUBLIC_API_URL
        : process.env.NEXT_PUBLIC_API_URL;

export const ApiConfig = {
    endpoints: {
        getHome: `${baseUrl}/v1/pages/home`,
        getSiteSettings: `${baseUrl}/v1/site_settings/list`,
        aboutUs: `${baseUrl}/v1/pages/about`,
        services: `${baseUrl}/v1/pages/services`,
        submitCareer: `${baseUrl}/v1/forms/careers`,
        getCareersPage: `${baseUrl}/v1/pages/careers`,
        submitContactUs: `${baseUrl}/v1/forms/contact`,
        getContactUsPage: `${baseUrl}/v1/pages/contact`,
        newsPage: `${baseUrl}/v1/pages/news`,
        getNews: `${baseUrl}/v1/news/list?page=1&posts_per_page=200`,
        getNewsDetails: `${baseUrl}/v1/news/details/`,
        getProducts: `${baseUrl}/v1/products/list`,
        categories: `${baseUrl}/v1/products/categories`,
        productDetails: `${baseUrl}/v1/products/details/`,
    },
    headers: {
        "Content-Type": "application/json",
        Accept: "application/json",
    },
    formHeaders: {
        Accept: "application/json",
    }
};
export const handleApiRequest = async (url, from = "home", method = "GET", body = null, isForm = false, side = "server") => {
    const locale = side === "server" ? await getLocale() : (localStorage.getItem("locale") || "en");
    console.log(locale);
    const response = await fetch(url, {
        method: method,
        headers: isForm ? {
            ...ApiConfig.formHeaders,
            lang: locale.lang
        } : {
            ...ApiConfig.headers,
            lang: locale.lang
        },
        cache: "no-cache",
        body: body,

    });
    if (from === "layout") console.log(response);
    if (!response.ok || response?.data?.status !== 200 || response?.status !== 200) {
        const error = await response.json();
        console.log(error);
        return error;
        //throw new Error(error.message);
    }
    return response.json();
};
